@@ -498,7 +498,8 @@ def test_corr_vector_operations():
 
 def test_spaghetti_plot():
     corr = _gen_corr(12, 50)
-    corr += pe.pseudo_Obs(0.0, 0.1, 'another_ensemble')
+    corr += pe.pseudo_Obs(0.0, 0.1, 'another_ensemble|r0')
+    corr += pe.pseudo_Obs(0.0, 0.1, 'another_ensemble|r1')
     corr += pe.cov_Obs(0.0, 0.01 ** 2, 'covobs')
 
     corr.spaghetti_plot(True)
@@ -531,3 +532,23 @@ def test_prune():
     with pytest.raises(Exception):
         corr_mat.prune(3)
         corr_mat.prune(4)
+
+
+def test_complex_Corr():
+    o1 = pe.pseudo_Obs(1.0, 0.1, "test")
+    cobs = pe.CObs(o1, -o1)
+    ccorr = pe.Corr([cobs, cobs, cobs])
+    assert np.all([ccorr.imag[i] == -ccorr.real[i] for i in range(ccorr.T)])
+    print(ccorr)
+    mcorr = pe.Corr(np.array([[ccorr, ccorr], [ccorr, ccorr]]))
+    assert np.all([mcorr.imag[i] == -mcorr.real[i] for i in range(mcorr.T)])
+
+
+def test_corr_no_filtering():
+    li = [-pe.pseudo_Obs(.2, .1, 'a', samples=10) for i in range(96)]
+    for i in range(len(li)):
+        li[i].idl['a'] = range(1, 21, 2)
+    c= pe.Corr(li)
+    b = pe.pseudo_Obs(1, 1e-11, 'a', samples=30)
+    c *= b
+    assert np.all([c[0].idl == o.idl for o in c])
